==> kubernetes-mock-1.3.67-sources.jar: io/fabric8/kubernetes/client/mock/impl/donable/MockDoneableDeployment.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.                                        
 *                                                                         
 * Licensed under the Apache License, Version 2.0 (the "License");         
 * you may not use this file except in compliance with the License.        
 * You may obtain a copy of the License at                                 
 *                                                                         
 *         http://www.apache.org/licenses/LICENSE-2.0                      
 *                                                                         
 * Unless required by applicable law or agreed to in writing, software     
 * distributed under the License is distributed on an "AS IS" BASIS,       
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and     
 * limitations under the License.
 */

package io.fabric8.kubernetes.client.mock.impl.donable;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.extensions.DoneableDeployment;
import io.fabric8.kubernetes.api.model.extensions.Deployment;
import io.fabric8.kubernetes.api.model.extensions.DeploymentBuilder;
import io.fabric8.kubernetes.api.model.extensions.DeploymentFluent;
import io.fabric8.kubernetes.api.model.extensions.DeploymentFluentImpl;
import io.fabric8.kubernetes.client.mock.MockDoneable;
import org.easymock.EasyMock;
import org.easymock.IExpectationSetters;

public class MockDoneableDeployment extends DeploymentFluentImpl<MockDoneableDeployment> implements MockDoneable<Deployment> {

  private interface DelegateInterface extends Doneable<Deployment>, DeploymentFluent<DoneableDeployment> {}
  private final Visitor<Deployment> visitor = new Visitor<Deployment>() {
    @Override
    public void visit(Deployment item) {}
  };

  private final DelegateInterface delegate;

  public MockDoneableDeployment() {
    super(new DeploymentBuilder()
      .withNewMetadata().endMetadata()
      .withNewSpec().endSpec()
      .withNewStatus().endStatus()
      .build());
    this.delegate = EasyMock.createMock(DelegateInterface .class);
  }

  @Override
  public IExpectationSetters<Deployment> done() {
    return EasyMock.expect(delegate.done());
  }

  @Override
  public Void replay() {
    EasyMock.replay(delegate);
    return null;
  }

  @Override
  public void verify() {
    EasyMock.verify(delegate);
  }

  @Override
  public Doneable<Deployment> getDelegate() {
    return new DoneableDeployment(new DeploymentBuilder(this).build(), visitor) {
      @Override
      public Deployment done() {
        return delegate.done();
      }
    };
  }
}

==> kubernetes-mock-1.4.4-sources.jar: io/fabric8/kubernetes/client/mock/impl/donable/MockDoneableDeployment.java <==
/**
 * Copyright (C) 2015 Red Hat, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.fabric8.kubernetes.client.mock.impl.donable;

import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.extensions.Deployment;
import io.fabric8.kubernetes.api.model.extensions.DeploymentBuilder;
import io.fabric8.kubernetes.api.model.extensions.DeploymentFluent;
import io.fabric8.kubernetes.api.model.extensions.DeploymentFluentImpl;
import io.fabric8.kubernetes.api.model.extensions.DoneableDeployment;
import io.fabric8.kubernetes.client.mock.MockDoneable;
import org.easymock.EasyMock;
import org.easymock.IExpectationSetters;

public class MockDoneableDeployment extends DeploymentFluentImpl<MockDoneableDeployment> implements MockDoneable<Deployment> {

  private interface DelegateInterface extends Doneable<Deployment>, DeploymentFluent<DoneableDeployment> {}

  private final Function<Deployment, Deployment> visitor = new Function<Deployment, Deployment>() {
    @Override
    public Deployment apply(Deployment item) {
      return item;
    }
  };

  private final DelegateInterface delegate;

  public MockDoneableDeployment() {
    super(new DeploymentBuilder()
      .withNewMetadata().endMetadata()
      .withNewSpec().endSpec()
      .withNewStatus().endStatus()
      .build());
    this.delegate = EasyMock.createMock(DelegateInterface .class);
  }

  @Override
  public IExpectationSetters<Deployment> done() {
    return EasyMock.expect(delegate.done());
  }

  @Override
  public Void replay() {
    EasyMock.replay(delegate);
    return null;
  }

  @Override
  public void verify() {
    EasyMock.verify(delegate);
  }

  @Override
  public Doneable<Deployment> getDelegate() {
    return new DoneableDeployment(new DeploymentBuilder(this).build(), visitor) {
      @Override
      public Deployment done() {
        return delegate.done();
      }
    };
  }
}
